==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_Gauge.h <==
//----------------------------------------------------------------------------
// wxGauge
// extracted from gauge.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GAUGE_H__
#define __CLASS_WX_GAUGE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGauge
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_Gauge);

//----------------------------------------------------------------------------
// Object declaration for wxGauge
//----------------------------------------------------------------------------
class Object_wx_Gauge : public Object_wx_Control {
public:
	Gura_DeclareObjectAccessor(wx_Gauge)
public:
	inline Object_wx_Gauge(wxGauge *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Control(Gura_UserClass(wx_Gauge), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_Gauge(Class *pClass, wxGauge *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Control(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_Gauge();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGauge *GetEntity() {
		return dynamic_cast<wxGauge *>(_pEntity);
	}
	inline wxGauge *ReleaseEntity() {
		wxGauge *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxGauge");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_Gauge.h <==
//----------------------------------------------------------------------------
// wxGauge
// extracted from gauge.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_GAUGE_H__
#define __CLASS_WX_GAUGE_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxGauge
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_Gauge);

//----------------------------------------------------------------------------
// Object declaration for wxGauge
//----------------------------------------------------------------------------
class Object_wx_Gauge : public Object_wx_Control {
public:
	Gura_DeclareObjectAccessor(wx_Gauge)
public:
	inline Object_wx_Gauge(wxGauge *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Control(Gura_UserClass(wx_Gauge), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_Gauge(Class *pClass, wxGauge *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Control(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_Gauge();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxGauge *GetEntity() {
		return dynamic_cast<wxGauge *>(_pEntity);
	}
	inline wxGauge *ReleaseEntity() {
		wxGauge *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxGauge");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
